@@ -150,7 +150,7 @@ end
 
 
 
-def create_code(name, flag)
+def create_code(name, flag, debug)
   def_fname = File.join(TOPDIR, "dev", "defs", name)
   hash = nil
   begin
@@ -255,7 +255,7 @@ def create_code(name, flag)
     inputs.delete(k)
   end
 
-  if @@debug
+  if debug
     p "inputs"
     p inputs
     p "outputs"
@@ -481,7 +481,7 @@ EOF
   end
   order = new_order
 
- if @@debug
+ if debug
    p "order"
    pp order
  end
@@ -756,14 +756,14 @@ EOF
   return [code_all, sub_name]
 end
 
-def generate_code(fnames, names)
+def generate_code(fnames, names, debug)
   nfnames = fnames.length
   sub_names = Array.new
   fnames.each_with_index{|fname,i|
     print "#{i+1}/#{nfnames}\n" if (i+1)%100==0
     name = File.basename(fname)
     flag = names.nil? || names.include?(name)
-    code, sub_name = create_code(name, flag)
+    code, sub_name = create_code(name, flag, debug)
     if code
       sub_names.push sub_name
       if flag
@@ -846,7 +846,7 @@ end
 
 
 
-@@debug = ARGV.delete("--debug")
+debug = ARGV.delete("--debug")
 
 #dname = ARGV.shift || raise("Usage: ruby #$0 path_to_lapack_src [name0, name1, ..]")
 dname = File.join(TOPDIR, "dev", "defs")
@@ -856,7 +856,7 @@ end
 
 unless ARGV.empty?
   names = ARGV
-  @@debug = true
+  debug = true
 else
   names = nil
 end
@@ -864,4 +864,4 @@ end
 reg = File.join(dname, "[a-z]*[a-z0-9]")
 fnames = Dir[reg]
 
-generate_code(fnames, names)
+generate_code(fnames, names, debug)
