@@ -1,3 +1,7 @@
+begin
+  require "rubygems"
+rescue LoadError
+end
 require "narray"
 require "numru/lapack.so"
 
